@@ -232,7 +232,7 @@ def north_money_stock(n=1):
     df.columns = [
         "序号","_","_","日期","_","名称","_","_","代码","_", "_","_","_",
         "持股数","持股市值","持股占流通股比","持股占总股本比",
-        "收盘价","涨跌幅","_","所属板块","_","_","_","_","_","_","_", "_",
+        "收盘","涨幅","_","所属板块","_","_","_","_","_","_","_", "_",
         "_","_", f'{period}增持市值',f'{period}增持股数',f'{period}增持市值增幅',
         f'{period}增持占流通股比',f'{period}增持占总股本比',
         "_","_","_","_","_","_","_",]
