@@ -12,7 +12,7 @@ import requests
 import pandas as pd
 import multitasking
 from tqdm import tqdm
-from retry import retry
+from func_timeout import func_set_timeout
 
 from jsonpath import jsonpath
 from datetime import datetime, timedelta
@@ -22,6 +22,60 @@ from qstock.data.util import (request_header, session, market_num_dict,
 
 signal.signal(signal.SIGINT, multitasking.killall)
 
+#获取某市场所有股票/债券/基金代码
+def get_code(market='沪深A'):
+    """
+    获取某市场交易标的代码和名称
+     market表示行情名称或列表，默认沪深A股
+    '沪深京A':沪深京A股市场; '沪深A':沪深A股市场;'沪A':沪市A股市场
+    '深A':深市A股市场;北A :北证A股市场;'可转债':沪深可转债市场;
+    '期货':期货市场;'创业板':创业板市场行情;'美股':美股市场;
+    '港股':港股市场;'中概股':中国概念股市场;'新股':沪深新股市场;
+    '科创板':科创板市场;'沪股通' 沪股通市场;'深股通':深股通市场;
+    '行业板块':行业板块市场;'概念板块':概念板块市场;
+    '沪深指数':沪深系列指数市场;'上证指数':上证系列指数市场
+    '深证指数':深证系列指数市场;'ETF' ETF基金市场;'LOF' LOF 基金市场
+    """
+    df=market_realtime(market)
+    codes=list(df['代码'])
+    return codes
+
+#获取某市场所有股票/债券/基金名称
+def get_name(market='沪深A'):
+    """
+    获取某市场交易标的代码和名称
+     market表示行情名称或列表，默认沪深A股
+    '沪深京A':沪深京A股市场; '沪深A':沪深A股市场;'沪A':沪市A股市场
+    '深A':深市A股市场;北A :北证A股市场;'可转债':沪深可转债市场;
+    '期货':期货市场;'创业板':创业板市场行情;'美股':美股市场;
+    '港股':港股市场;'中概股':中国概念股市场;'新股':沪深新股市场;
+    '科创板':科创板市场;'沪股通' 沪股通市场;'深股通':深股通市场;
+    '行业板块':行业板块市场;'概念板块':概念板块市场;
+    '沪深指数':沪深系列指数市场;'上证指数':上证系列指数市场
+    '深证指数':深证系列指数市场;'ETF' ETF基金市场;'LOF' LOF 基金市场
+    """
+    df=market_realtime(market)
+    names=list(df['名称'])
+    return names
+
+#获取某市场所有股票/债券/基金名称代码字典
+def get_name_code(market='沪深A'):
+    """
+    获取某市场交易标的代码和名称
+     market表示行情名称或列表，默认沪深A股
+    '沪深京A':沪深京A股市场; '沪深A':沪深A股市场;'沪A':沪市A股市场
+    '深A':深市A股市场;北A :北证A股市场;'可转债':沪深可转债市场;
+    '期货':期货市场;'创业板':创业板市场行情;'美股':美股市场;
+    '港股':港股市场;'中概股':中国概念股市场;'新股':沪深新股市场;
+    '科创板':科创板市场;'沪股通' 沪股通市场;'深股通':深股通市场;
+    '行业板块':行业板块市场;'概念板块':概念板块市场;
+    '沪深指数':沪深系列指数市场;'上证指数':上证系列指数市场
+    '深证指数':深证系列指数市场;'ETF' ETF基金市场;'LOF' LOF 基金市场
+    """
+    df=market_realtime(market)
+    name_code_dict=dict(df[['名称','代码']].values)
+    return name_code_dict
+
 # 获取某指定市场所有标的最新行情指标
 def market_realtime(market='沪深A'):
     """
@@ -288,7 +342,7 @@ def stock_snapshot(code):
 
 
 # 获取最近n日（最多五天）的1分钟数据
-@retry(tries=3)
+
 def get_1min_data(code, n=5):
     """
     获取股票、期货、债券的最近n日的1分钟K线行情
@@ -516,26 +570,38 @@ def latest_trade_date():
     
 
 # 获取单只或多只证券（股票、基金、债券、期货)的收盘价格dataframe
-def get_price(code_list, start='19000101', end='20500101', freq='d', fqt=1):
+def get_price(code_list, start='19000101', end=None, freq='d', fqt=1):
     '''code_list输入股票list列表
     如code_list=['中国平安','贵州茅台','工业富联']
     '''
     if isinstance(code_list, str):
         code_list = [code_list]
+    
+    if end is None:
+        end=latest_trade_date()
 
     @multitasking.task
-    @retry(tries=3, delay=1)
+    @func_set_timeout(5)
     def run(code):
-        temp = web_data(code, start, end, freq, fqt)
-        name = temp.name.iloc[-1]
-        data[name] = temp.close
-
-    data = pd.DataFrame()
-    for code in tqdm(code_list):
-        run(code)
+        try:
+            temp = web_data(code, start, end, freq, fqt)
+            temp[temp.name[0]]=temp.close
+            data_list.append(temp[temp.name[0]])
+            pbar.update()
+        except:
+            pass
+    pbar = tqdm(total=len(code_list))
+    data_list = []
+    for code in code_list:
+        try:
+            run(code)
+        except:
+            continue
     multitasking.wait_for_tasks()
+    # 转换为dataframe
+    df = pd.concat(data_list, axis=1)
+    return df
 
-    return data
 
 # 获取单只或多只证券（股票、基金、债券、期货)的历史K线数据
 def get_data(code_list, start='19000101', end=None, freq='d', fqt=1):
@@ -549,20 +615,93 @@ def get_data(code_list, start='19000101', end=None, freq='d', fqt=1):
         end=latest_trade_date()
 
     data_list = []
-
+    pbar = tqdm(total=len(code_list))
+    
     @multitasking.task
-    @retry(tries=3, delay=1)
+    @func_set_timeout(5)
     def run(code):
         data = web_data(code, start, end, freq, fqt)
         data_list.append(data)
-
-    for code in tqdm(code_list):
+        pbar.update()
+    for code in code_list:
         run(code)
     multitasking.wait_for_tasks()
     # 转换为dataframe
     df = pd.concat(data_list, axis=0)
     return df
 
+#获取沪深指数对应代码名称字典
+def index_code_name():
+    df=realtime_data('沪深指数')
+    code_name_dict=dict((df[['代码','名称']].values))
+    return code_name_dict
+
+#获取指数历史交易数据
+def get_index_data(code_list, start='19000101', end=None, freq='d'):
+    
+    if isinstance(code_list, str):
+        code_list = [code_list]
+    if end is None:
+        end=latest_trade_date()
+
+    data_list = []
+    pbar = tqdm(total=len(code_list))
+    
+    @multitasking.task
+    @func_set_timeout(5)
+    def run(code):
+        data = web_data(code, start=start, end=end, freq=freq)
+        data_list.append(data)
+        pbar.update()
+    for code in code_list:
+        if code.isdigit():
+            code_name_dict=index_code_name()
+            code=code_name_dict[code]
+        run(code)
+    multitasking.wait_for_tasks()
+    # 转换为dataframe
+    df = pd.concat(data_list, axis=0)
+    return df
+
+# 获取指数价格数据
+def get_index_price(code_list, start='19000101', end=None, freq='d'):
+    '''code_list输入指数list列表
+   
+    '''
+    
+    if isinstance(code_list, str):
+        code_list = [code_list]
+    
+    if end is None:
+        end=latest_trade_date()
+
+    @multitasking.task
+    @func_set_timeout(5)
+    def run(code):
+        try:
+            temp = web_data(code, start, end, freq)
+            temp[temp.name[0]]=temp.close
+            data_list.append(temp[temp.name[0]])
+            pbar.update()
+        except:
+            pass
+            
+    pbar = tqdm(total=len(code_list))
+    data_list = []
+    for code in tqdm(code_list):
+        if code.isdigit():
+            code_name_dict=index_code_name()
+            code=code_name_dict[code]
+        try:
+            run(code)
+        except:
+            continue
+    multitasking.wait_for_tasks()
+    # 转换为dataframe
+    df = pd.concat(data_list, axis=1)
+    return df
+
+
 ###股票数据接口
 # 获取单只个股最新的基本财务指标
 def stock_info(code):
@@ -618,11 +757,6 @@ def stock_basics(code_list):
     df = trans_num(df, cols)
     return df
 
-
-
-
-
-
 # 获取沪深市场全部股票报告期信息
 def report_date():
     """
@@ -899,18 +1033,19 @@ def stock_sector(code):
     df = pd.DataFrame(res.json()['data']['diff']).T
     df.index = range(len(df))
     filelds = {
-        'f12': '板块代码',
-        'f14': '板块名称',
-        'f3': '板块涨幅',
+        'f12': '代码',
+        'f14': '简称',
+        'f3': '涨幅',
     }
     df = df.rename(columns=filelds)[filelds.values()]
     code = code_id.split('.')[-1]
     # df.insert(0, '股票名称', name)
-    df.insert(1, '股票代码', code)
-    df['板块涨幅'] = (df['板块涨幅'].astype('float') / 100)
+    #df.insert(1, '代码', code)
+    cols = ['代码', '简称']
+    df = trans_num(df, cols).round(3)
+    #df['涨幅'] = (df['涨幅']/ 100)
     return df
 
-
 ##############################################################################
 ####基金fund
 
@@ -925,7 +1060,6 @@ fund_header = {
 
 
 # 获取基金单位净值（当前净资产大小）和累计净值（自成立以来的整体收益情况）
-@retry(tries=3)
 def fund_data_single(code):
     """
     根据基金代码和要获取的页码抓取基金净值信息
@@ -985,13 +1119,14 @@ def fund_price(code_list):
     '''
 
     @multitasking.task
-    @retry(tries=3, delay=1)
+    @func_set_timeout(5)
     def run(code):
         temp = fund_data_single(code)
         data[code] = temp['累计净值']
-
+        pbar.update()
+    pbar = tqdm(total=len(code_list))
     data = pd.DataFrame()
-    for code in tqdm(code_list):
+    for code in code_list:
         run(code)
     multitasking.wait_for_tasks()
 
@@ -1007,23 +1142,22 @@ def fund_data(code_list):
     if isinstance(code_list, str):
         code_list = [code_list]
     data_list = []
-
+    pbar = tqdm(total=len(code_list))
+    
     @multitasking.task
-    @retry(tries=3, delay=1)
+    @func_set_timeout(5)
     def run(code):
         data = fund_data_single(code)
         data['code'] = code
         data_list.append(data)
-
-    for code in tqdm(code_list):
+        pbar.update()
+    for code in code_list:
         run(code)
     multitasking.wait_for_tasks()
     # 转换为dataframe
     df = pd.concat(data_list, axis=0)
     return df
 
-
-@retry(tries=3)
 def fund_code(ft=None):
     """
     获取天天基金网公开的全部公墓基金名单
@@ -1071,7 +1205,6 @@ def fund_code(ft=None):
     return df
 
 
-@retry(tries=3)
 def fund_position(code, n=1):
     '''code:基金代码，n:获取最近n期数据，n默认为1表示最近一期数据
     '''
@@ -1143,7 +1276,6 @@ def fund_dates(code):
     return json_response['Datas']
 
 
-@retry(tries=3)
 def fund_perfmance(code):
     """
     获取基金阶段涨跌幅度
@@ -1191,7 +1323,6 @@ def fund_perfmance(code):
     return df
 
 
-@retry(tries=3)
 def fund_base_info(code):
     """
     获取基金的一些基本信息
@@ -1231,26 +1362,26 @@ def fund_base_info(code):
     return ss
 
 
-def fund_info(code=None, ft='gp'):
+def fund_info(code_list=None, ft='gp'):
     """
     获取基金基本信息
     code:可以输入单只基金代码或多只基金的list
     """
-    if code is None:
-        code = list(fund_code(ft)['基金代码'])
-    if isinstance(code, str):
-        code = [code]
+    if code_list is None:
+        code_list = list(fund_code(ft)['基金代码'])
+    if isinstance(code_list, str):
+        code_list = [code_list]
     ss = []
 
     @multitasking.task
-    @retry(tries=3, delay=1)
+    @func_set_timeout(5)
     def start(code):
         s = fund_base_info(code)
         ss.append(s)
         pbar.update()
 
-    pbar = tqdm(total=len(code))
-    for c in code:
+    pbar = tqdm(total=len(code_list))
+    for c in code_list:
         start(c)
     multitasking.wait_for_tasks()
     df = pd.DataFrame(ss)
@@ -1348,10 +1479,13 @@ def bond_info(code_list=None):
     ss = []
 
     @multitasking.task
+    @func_set_timeout(5)
     def run(code):
         s = bond_info_single(code)
         ss.append(s)
+        pbar.update()
 
+    pbar = tqdm(total=len(code_list))
     for code in code_list:
         run(code)
     multitasking.wait_for_tasks()
