@@ -7,7 +7,7 @@
 import time
 import requests
 import pandas as pd
-from retry.api import retry
+
 from pathlib import Path
 from py_mini_racer import py_mini_racer
 
@@ -477,7 +477,6 @@ ths_code_name = {
         "884274": "IT服务",
     }
 
-@retry(tries=3, delay=1)
 def get_code_id(code):
     """
     生成东方财富股票专用的行情ID
@@ -509,7 +508,7 @@ def trans_num(df, ignore_cols):
 
 #同花顺股票池
 
-def get_ths_header():
+def ths_header():
     file= Path(__file__).parent/"ths.js"
     with open(file) as f:
         js_data = f.read()
@@ -519,5 +518,5 @@ def get_ths_header():
     headers = {
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36",
         "Cookie": f"v={v_code}",
-        }
-    return headers
+    }
+    return headers
\ No newline at end of file
